pub trait LogsHandler:
Send
+ Sync
+ 'static {
// Required method
fn handle_operation(
&self,
op: LogsOperation,
body: Bytes,
) -> Pin<Box<dyn Future<Output = Result<Response<LogsResponseBody>, LogsError>> + Send>>;
}Expand description
Trait that the CloudWatch Logs business logic provider must implement.
The handler receives a parsed operation enum and the raw JSON body bytes, and returns a complete HTTP response. This trait serves as the boundary between the HTTP transport layer and the business logic layer.
Required Methods
Sourcefn handle_operation(
&self,
op: LogsOperation,
body: Bytes,
) -> Pin<Box<dyn Future<Output = Result<Response<LogsResponseBody>, LogsError>> + Send>>
fn handle_operation( &self, op: LogsOperation, body: Bytes, ) -> Pin<Box<dyn Future<Output = Result<Response<LogsResponseBody>, LogsError>> + Send>>
Handle a CloudWatch Logs operation and produce an HTTP response.